@@ -63,7 +63,7 @@ class Hardrules():
     rule_pipeline['no_bad_encoding'] = True
     rule_pipeline['no_titles'] = True
     rule_pipeline['no_wrong_language'] = True
-    rule_pipeline['no_porn'] = 'sl'
+    rule_pipeline['no_porn'] = True
     rule_pipeline['lm_filter'] = True
 
     def __init__(self, args):
@@ -78,14 +78,18 @@ class Hardrules():
 
         # Load porn removal
         if not args.disable_porn_removal:
-            self.porn_removal_side = args.metadata_yaml['porn_removal_side']
-            self.porn_removal = args.porn_removal
-            if self.porn_removal_side == 'tl':
-                self.porn_tokenizer = Tokenizer(args.target_tokenizer_command,
-                                                args.target_lang)
-            else:
-                self.porn_tokenizer = Tokenizer(args.source_tokenizer_command,
-                                                args.source_lang)
+            try:
+                self.porn_removal_side = args.metadata_yaml['porn_removal_side']
+                self.porn_removal = args.porn_removal
+                if self.porn_removal_side == 'tl':
+                    self.porn_tokenizer = Tokenizer(args.target_tokenizer_command, args.target_lang)
+                else:
+                    self.porn_tokenizer = Tokenizer(args.source_tokenizer_command, args.source_lang)                
+            except KeyError:
+                self.porn_removal = None
+                self.porn_tokenizer = None
+                self.porn_removal_side = None
+                    
         else:
             self.porn_removal = None
             self.porn_tokenizer = None
@@ -292,7 +296,7 @@ class Hardrules():
     def c_no_porn(self, left, right):
         if self.porn_removal is None:
             return True
-
+    
         if self.porn_removal_side == "sl":
             tok = self.porn_tokenizer.tokenize(left.lower())
         elif self.porn_removal_side == "tl":
